smartcard.pcsc.PCSCExceptions

# ``smartcard`.`pcsc`.`PCSCExceptions``

module documentation

Smartcard module exceptions.

This module defines the exceptions raised by the smartcard.pcsc modules.

__author__ = "http://www.gemalto.com"

Copyright 2001-2012 gemalto Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com

This file is part of pyscard.

pyscard is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

pyscard is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with pyscard; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Exception | `AddReaderToGroupException` | Raised when scard fails to add a new reader to a PCSC reader group.
Exception | `BaseSCardException` | Base class for scard (aka PCSC) exceptions.
Exception | `EstablishContextException` | Raised when scard failed to establish context with PCSC.
Exception | `IntroduceReaderException` | Raised when scard fails to introduce a new reader to PCSC.
Exception | `ListReadersException` | Raised when scard failed to list readers.
Exception | `ReleaseContextException` | Raised when scard failed to release PCSC context.
Exception | `RemoveReaderFromGroupException` | Raised when scard fails to remove a reader from a PCSC reader group.